load_spec

Function load_spec 

pub fn load_spec(input: &str) -> Result<String, Box<dyn Error>>
Load a local or remote OpenAPI document with bounded remote I/O.

HTTPS is accepted everywhere. Plain HTTP is accepted only for loopback hosts so local development and deterministic integration tests do not need a certificate while non-local traffic remains encrypted.