Module http_config

Module http_config 

Runtime HTTP client configuration types

These types are used by generated code at runtime and represent the actual configuration that will be used by the HTTP client.

Structs

HttpClientConfig
Runtime HTTP client configuration (used by generated code)
RetryConfig
Retry configuration for HTTP requests

Enums

AuthConfig
Authentication configuration