render

Function render 

pub fn render(
    index: &OperationIndex,
    filter: &ListFilter,
    output: ListOutput,
) -> (String, usize)
Render selected operations as either an aligned table or JSON. Returns the rendered string and the count of matched operations.