pub fn select<'a>(
index: &'a OperationIndex,
filter: &ListFilter,
) -> Vec<&'a OperationSummary>Expand description
Apply filters and return the matching operations in index order.
pub fn select<'a>(
index: &'a OperationIndex,
filter: &ListFilter,
) -> Vec<&'a OperationSummary>Apply filters and return the matching operations in index order.