Runtime HTTP client configuration types
These types are used by generated code at runtime and represent the actual configuration that will be used by the HTTP client.
Structs
- Http
Client Config - Runtime HTTP client configuration (used by generated code)
- Retry
Config - Retry configuration for HTTP requests
Enums
- Auth
Config - Authentication configuration